pub trait Reporter: Send + Sync {
// Required methods
fn step_start(&self, msg: &str);
fn step_done(&self, msg: &str);
fn step_fail(&self, msg: &str);
// Provided methods
fn info(&self, msg: &str) { ... }
fn remote_line(&self, line: &str) { ... }
}Expand description
How the engine tells the outside world what it is doing.
A “step” is one unit of work (detect runner, build, upload, restart). The
engine brackets each with step_start and one of
step_done / step_fail.
Required Methods
Sourcefn step_start(&self, msg: &str)
fn step_start(&self, msg: &str)
A unit of work has started.
Provided Methods
Sourcefn remote_line(&self, line: &str)
fn remote_line(&self, line: &str)
A single line of streamed output from a build or the remote (e.g. a line
of next build output, or a git receive-pack message). Defaults to no-op.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".